==> haskell-arrows-0.4.4.2-144-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-arrows.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arrows
version:              0.4.4.2
visibility:           public
id:                   arrows-0.4.4.2-JNj3DUFLHfV7GnWb87ZsdX
key:                  arrows-0.4.4.2-JNj3DUFLHfV7GnWb87ZsdX
license:              BSD-3-Clause
maintainer:           Ross Paterson <R.Paterson@city.ac.uk>
author:               Ross Paterson <R.Paterson@city.ac.uk>
homepage:             http://www.haskell.org/arrows/
synopsis:             Arrow classes and transformers
description:
    Several classes that extend the Arrow class, and some
    transformers that implement or lift these classes.

category:             Control
abi:                  742bdecba1548511693da0fbbd5fd4a3
exposed:              True
exposed-modules:
    Control.Arrow.Operations Control.Arrow.Transformer
    Control.Arrow.Transformer.All Control.Arrow.Transformer.Automaton
    Control.Arrow.Transformer.CoState Control.Arrow.Transformer.Error
    Control.Arrow.Transformer.Reader Control.Arrow.Transformer.State
    Control.Arrow.Transformer.Static Control.Arrow.Transformer.Stream
    Control.Arrow.Transformer.Writer

hidden-modules:       Control.Arrow.Internals
import-dirs:          /usr/lib/ghc-9.4.8/site-local/arrows-0.4.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/arrows-0.4.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/arrows-0.4.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arrows
hs-libraries:         HSarrows-0.4.4.2-JNj3DUFLHfV7GnWb87ZsdX
depends:              Stream-0.4.7.2-DLonMoM0xMPHRX6rYrVFgp base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-arrows/html/arrows.haddock
haddock-html:         /usr/share/doc/haskell-arrows/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-arrows-0.4.4.2-145-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-arrows.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arrows
version:              0.4.4.2
visibility:           public
id:                   arrows-0.4.4.2-FVtrPoUQ6sGGCX3vjRrszK
key:                  arrows-0.4.4.2-FVtrPoUQ6sGGCX3vjRrszK
license:              BSD-3-Clause
maintainer:           Ross Paterson <R.Paterson@city.ac.uk>
author:               Ross Paterson <R.Paterson@city.ac.uk>
homepage:             http://www.haskell.org/arrows/
synopsis:             Arrow classes and transformers
description:
    Several classes that extend the Arrow class, and some
    transformers that implement or lift these classes.

category:             Control
abi:                  6e266a65a2dad736331010d806f26d1b
exposed:              True
exposed-modules:
    Control.Arrow.Operations Control.Arrow.Transformer
    Control.Arrow.Transformer.All Control.Arrow.Transformer.Automaton
    Control.Arrow.Transformer.CoState Control.Arrow.Transformer.Error
    Control.Arrow.Transformer.Reader Control.Arrow.Transformer.State
    Control.Arrow.Transformer.Static Control.Arrow.Transformer.Stream
    Control.Arrow.Transformer.Writer

hidden-modules:       Control.Arrow.Internals
import-dirs:          /usr/lib/ghc-9.4.8/site-local/arrows-0.4.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/arrows-0.4.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/arrows-0.4.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arrows
hs-libraries:         HSarrows-0.4.4.2-FVtrPoUQ6sGGCX3vjRrszK
depends:              Stream-0.4.7.2-DoKYXc2gTCB8yLwYENobqd base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-arrows/html/arrows.haddock
haddock-html:         /usr/share/doc/haskell-arrows/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
